/* global Phaser */
import BootScene from './scenes/Boot'
import MainScene from './scenes/Main'
import SplashScene from './scenes/Splash'
import GameOverScene from './scenes/GameOver'

const DEFAULT_WIDTH = 1080
const DEFAULT_HEIGHT = 1920

const defaultFont = 'Bubblegum Sans'

// Calistoga
// Carter One
// Margarine
// Bubblegum Sans
// Lemon
// Yeon Sung

// Chewy
// Lobster
// Uncial Antiqua

export default {
	backgroundColor: '#9f6741',
	scale: {
		parent: 'phaser-game',
		mode: Phaser.Scale.FIT,
		autoCenter: Phaser.Scale.CENTER_BOTH,
		width: DEFAULT_WIDTH,
		height: DEFAULT_HEIGHT
	},
	scene: [BootScene, SplashScene, MainScene, GameOverScene],
	webfonts: ['Bubblegum Sans'],
	materials: [{
		id: 'leather',
		name: 'Leder',
		icon: 'stoff',
		options: {
			color: 0x7f401c
		},
		stability: 4
	}, {
		id: 'iron',
		name: 'Eisen',
		icon: 'barren',
		options: {
			color: 0xa8a9ad
		},
		stability: 8
	}, {
		id: 'gold',
		name: 'Gold',
		icon: 'barren',
		options: {
			color: 0xfed700
		},
		stability: 4
	}, {
		id: 'moss',
		name: 'Moos',
		icon: 'stoecke',
		stability: 1
	}, {
		id: 'wood',
		name: 'Holz',
		icon: 'holz',
		options: {
			color: 0xc67c33
		},
		stability: 3
	}, {
		id: 'cloth',
		name: 'Stoff',
		icon: 'stoff',
		options: {
			color: 0x263089
		},
		stability: 1
	}, {
		id: 'cushions',
		name: 'Kissen',
		icon: 'kissen',
		stability: 2
	}],
	armors: [{
		id: 'leather',
		materialId: 'leather',
		image: 'lederruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0x7f401c
		}
	}, {
		id: 'iron',
		materialId: 'iron',
		image: 'eisenruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0xa8a9ad
		}
	}, {
		id: 'gold',
		materialId: 'gold',
		image: 'goldruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0xfed700
		}
	}, {
		id: 'moss',
		materialId: 'moss',
		image: 'holzruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0x784832 // 0x9f6741
		}
	}, {
		id: 'wood',
		materialId: 'wood',
		image: 'holzruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0xc67c33
		}
	}, {
		id: 'cloth',
		materialId: 'cloth',
		image: 'magierrobe',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0x263089
		}
	}, {
		id: 'cushions',
		materialId: 'cushions',
		image: 'kissenruestung',
		possibleHoles: [0, 1, 2, 3],
		options: {
			color: 0xffffff
		}
	}],
	possibleHoles: [{
		x: 0,
		y: -100,
		width: 500,
		height: 700
	}, {
		x: -500,
		y: -100,
		width: 500,
		height: 700
	}, {
		x: 0,
		y: -600,
		width: 500,
		height: 500
	}, {
		x: -500,
		y: -600,
		width: 500,
		height: 500
	}],
	initiallyStoredMaterials: 6,
	displayMaterialsPerRow: 4,
	numberOfSelectedMaterials: 3,
	counterTextStyle: {
		fontFamily: defaultFont,
		fontSize: 50,
		color: '#fff',
		stroke: '#000',
		strokeThickness: 4
	},
	timeTextStyle: {
		fontFamily: defaultFont,
		fontSize: 70,
		color: '#fff',
		stroke: '#000',
		strokeThickness: 4
	},
	buttonTextStyle: {
		fontFamily: defaultFont,
		fontSize: 70,
		color: '#fff',
		stroke: '#000',
		strokeThickness: 4
	},
	dialogTextStyle: {
		fontFamily: defaultFont,
		fontSize: 70,
		color: '#fff',
		stroke: '#000',
		strokeThickness: 4,
		align: 'left',
		wordWrap: {
			width: DEFAULT_WIDTH * 0.8
		}
	},
	snapBackDuration: 250,
	tools: [{
		id: 'hammer',
		name: 'Hammer',
		icon: 'hammer',
		options: {
			color: 0x242529
		}
	}, {
		id: 'tongs',
		name: 'Zange',
		icon: 'zange',
		options: {
			color: 0x757575
		}
	}, {
		id: 'knife',
		name: 'Messer',
		icon: 'messer',
		options: {
			color: 0xa8a9ad
		}
	}, {
		id: 'bucket',
		name: 'Wassereimer',
		icon: 'eimer',
		options: {
			color: 0x784832
		}
	}],
	toolsPerRow: 4
}
