import Phaser from 'phaser'

export default class BasicButton extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		const width = options.width
		const height = options.height
		this.activeState = false
		this.onClick = options.onClick
		this.disabled = false
		this.scaleOnClick = true
		this.currentPointer = null
		
		this.buttonContent = options.buttonContent
		if (this.buttonContent) {
			if (typeof this.buttonContent.setOrigin === 'function') {
				this.buttonContent.setOrigin(0.5, 0.5)
			}
			this.buttonContent.setPosition(0, 0)
			this.add(this.buttonContent)
		}
		
		this.clickArea = new Phaser.GameObjects.Zone(this.scene, 0, 0, width, height)
		this.clickArea.setOrigin(0.5, 0.5)
		this.setActiveState(true)
		this.clickArea.on('pointerdown', (pointer) => {
			if (!this.disabled) {
				this.currentPointer = pointer
				this.pointerDown()
			}
		})
		this.clickArea.on('pointerup', (pointer) => {
			if (!this.disabled && this.currentPointer === pointer) {
				this.currentPointer = null
				this.pointerUp()
			}
		})
		this.clickArea.on('pointerout', (pointer) => {
			if (!this.disabled && this.currentPointer === pointer) {
				this.currentPointer = null
				this.pointerOut()
			}
		})
		this.add(this.clickArea)
	}
	
	setActiveState (active) {
		if (this.activeState !== active) {
			if (active) {
				this.clickArea.setInteractive()
			} else {
				this.clickArea.disableInteractive()
			}
			
			this.activeState = active
		}
	}
	
	setDisabled (value) {
		this.disabled = value
		this.setActiveState(!value)
	}
	
	disable () {
		this.setDisabled(true)
	}
	
	enable () {
		this.setDisabled(false)
	}
	
	pointerDown () {
		if (this.scaleOnClick && this.buttonContent) {
			this.buttonContent.setScale(0.8, 0.8)
		}
	}
	
	pointerUp () {
		if (this.scaleOnClick && this.buttonContent) {
			this.buttonContent.setScale(1, 1)
		}
		if (typeof this.onClick === 'function') {
			this.onClick()
		}
	}
	
	pointerOut () {
		if (this.scaleOnClick && this.buttonContent) {
			this.buttonContent.setScale(1, 1)
		}
	}
}
