import Phaser from 'phaser'
import config from '../config'

export default class CustomerDisplay extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.updateCustomer(options.customer)
		this.onArmorFixed = options.onArmorFixed
	}
	
	addHole (holeIndex, holeId, mask) {
		const holeSpec = config.possibleHoles[holeId]
		const hole = new Phaser.GameObjects.Zone(this.scene, holeSpec.x, holeSpec.y, holeSpec.width, holeSpec.height)
		hole.setOrigin(0, 0)
		hole.setDropZone()
		hole.holeIndex = holeIndex
		this.holes[holeIndex] = hole
		
		mask.fillStyle(0xffffff)
		mask.fillRect(holeSpec.x, holeSpec.y, holeSpec.width, holeSpec.height)
		
		this.add(hole)
	}
	
	fixHole (holeIndex, material) {
		const holeId = this.customer.holes[holeIndex]
		const holeSpec = config.possibleHoles[holeId]
		const fixedArmor = config.armors.find((armor) => armor.materialId === material)
		
		if (fixedArmor) {
			this.fixed = new Phaser.GameObjects.Image(this.scene, 0, 0, fixedArmor.image)
			if (fixedArmor.options && fixedArmor.options.color) {
				this.fixed.setTint(fixedArmor.options.color)
			}
			this.fixed.setScale(0.7, 0.7)
			this.add(this.fixed)
			
			const mask = new Phaser.GameObjects.Graphics(this.scene)
			mask.fillStyle(0xffffff)
			mask.fillRect(holeSpec.x, holeSpec.y, holeSpec.width, holeSpec.height)
			mask.x = this.x
			mask.y = this.y
			this.fixed.mask = new Phaser.Display.Masks.GeometryMask(this, mask)
			
			this.customer.fixes[holeIndex] = material
			this.holes[holeIndex].destroy()
			
			if (this.customer.holes.every((hole, index) => this.customer.fixes[index])) {
				if (typeof this.onArmorFixed === 'function') {
					this.onArmorFixed()
				}
			}
		}
	}
	
	updateCustomer (customer) {
		this.customer = customer
		
		if (this.holes) {
			for (const hole of this.holes) {
				hole.destroy()
			}
		}
		if (this.armor) {
			this.armor.destroy()
		}
		if (this.fixed) {
			this.fixed.destroy()
		}
		
		this.holes = []
		const armorSpec = config.armors.find((armor) => armor.id === this.customer.armorId) || {}
		this.armor = new Phaser.GameObjects.Image(this.scene, 0, 0, armorSpec.image)
		if (armorSpec.options && armorSpec.options.color) {
			this.armor.setTint(armorSpec.options.color)
		}
		this.armor.setScale(0.7, 0.7)
		
		this.add(this.armor)
		
		const mask = new Phaser.GameObjects.Graphics(this.scene)
		mask.x = this.x
		mask.y = this.y
		for (let i = 0; i < this.customer.holes.length; i++) {
			const hole = this.customer.holes[i]
			this.addHole(i, hole, mask)
		}
		this.armor.mask = new Phaser.Display.Masks.GeometryMask(this, mask)
		this.armor.mask.setInvertAlpha(true)
	}
}
