import Phaser from 'phaser'
import config from '../config'
import StorageDisplay from '../widgets/StorageDisplay'
import TextButton from '../widgets/TextButton'

export default class LootDialog extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.clickSound = this.scene.sound.add('click')
		this.clickSound.setVolume(0.25)
		
		this.background = new Phaser.GameObjects.Graphics(this.scene)
		this.background.lineStyle(10, 0x7f401c, 1.0)
		this.background.fillStyle(0xc67c33, 1.0)
		this.background.fillRoundedRect(5, 5, this.scene.sys.canvas.width * 0.9, 1300, 20)
		this.background.strokeRoundedRect(5, 5, this.scene.sys.canvas.width * 0.9, 1300, 20)
		this.background.setPosition(this.scene.sys.canvas.width * 0.1 / 2, 0)

		this.survivingCustomersPrompt = new Phaser.GameObjects.Text(this.scene, this.scene.sys.canvas.width / 2, 80, 'Congratulations! Your are done working for today. 0 out of 0 heroes survived and brought you loot:', config.dialogTextStyle)
		this.survivingCustomersPrompt.setOrigin(0.5, 0)
		
		this.lootDisplay = new StorageDisplay({
			scene: this.scene
		})
		this.lootDisplay.setPosition(0, 700)
		
		this.nextDayButton = new TextButton({
			scene: this.scene,
			width: this.scene.sys.canvas.width * 0.75,
			height: 100,
			enabledStyle: config.buttonTextStyle,
			text: 'Sleep until tomorrow',
			background: 'buttonBackground',
			onClick: () => {
				if (typeof options.onClose === 'function') {
					options.onClose()
				}
				this.clickSound.play()
				this.hide()
			}
		})
		this.nextDayButton.setPosition(this.scene.sys.canvas.width / 2, 1200)
		
		this.add(this.background)
		this.add(this.survivingCustomersPrompt)
		this.add(this.lootDisplay)
		this.add(this.nextDayButton)
		this.visible = false
	}
	
	show (totalCustomers, survivingCustomers, loot) {
		this.survivingCustomersPrompt.setText('Congratulations! Your are done working for today. ' + survivingCustomers + ' out of ' + totalCustomers + ' heroes survived and brought you loot:')
		this.lootDisplay.updateCounts(loot)
		this.visible = true
	}
	
	hide () {
		this.visible = false
	}
}
