import Phaser from 'phaser'
import TextButton from '../widgets/TextButton'
import config from '../config'

export default class NextCustomerDialog extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.clickSound = this.scene.sound.add('click')
		this.clickSound.setVolume(0.25)
		
		this.background = new Phaser.GameObjects.Graphics(this.scene)
		this.background.lineStyle(10, 0x7f401c, 1.0)
		this.background.fillStyle(0xc67c33, 1.0)
		this.background.fillRoundedRect(5, 5, this.scene.sys.canvas.width * 0.9, 500, 20)
		this.background.strokeRoundedRect(5, 5, this.scene.sys.canvas.width * 0.9, 500, 20)
		this.background.setPosition(-this.scene.sys.canvas.width * 0.9 / 2, -50)
		
		this.waitingCustomersPrompt = new Phaser.GameObjects.Text(this.scene, 0, 0, 'There are 0 heroes waiting for you to repair their armor.', config.dialogTextStyle)
		this.waitingCustomersPrompt.setOrigin(0.5, 0)
		
		this.nextCustomerButton = new TextButton({
			scene: this.scene,
			width: this.scene.sys.canvas.width * 0.75,
			height: 100,
			enabledStyle: config.buttonTextStyle,
			text: 'Repair next armor',
			background: 'buttonBackground',
			onClick: () => {
				if (typeof options.onClose === 'function') {
					options.onClose()
				}
				this.clickSound.play()
				this.hide()
			}
		})
		this.nextCustomerButton.setPosition(0, 350)
		
		this.add(this.background)
		this.add(this.waitingCustomersPrompt)
		this.add(this.nextCustomerButton)
		this.visible = false
	}
	
	show (numberOfWaitingCustomers) {
		this.waitingCustomersPrompt.setText('There are ' + numberOfWaitingCustomers + ' heroes waiting for you to repair their armor.')
		this.visible = true
	}
	
	hide () {
		this.visible = false
	}
}
