import Phaser from 'phaser'
import config from '../config'
import SelectedMaterialDisplay from '../widgets/SelectedMaterialDisplay'

export default class RepairMaterialSelectionDisplay extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.materialDisplays = []
		
		this.background = new Phaser.GameObjects.Graphics(this.scene)
		this.add(this.background)
		
		const spacing = this.scene.sys.canvas.width / (config.numberOfSelectedMaterials + 1)
		
		this.background.fillStyle(0x6e3b28)
		this.background.fillRect(0, -spacing / 2, this.scene.sys.canvas.width, 1000)

		this.background.fillStyle(0x441d16)
		this.background.fillRect(0, -spacing / 2, this.scene.sys.canvas.width, spacing)
		
		for (let i = 0; i < config.numberOfSelectedMaterials; i++) {
			const materialIndex = i
			const display = new SelectedMaterialDisplay({
				scene: this.scene,
				material: {
					icon: ''
				},
				width: 350,
				height: 350,
				onDropped: () => {
					if (typeof this.onDropped === 'function') {
						this.onDropped(materialIndex)
					}
				}
			})
			this.materialDisplays.push(display)
			display.updateMaterial()
			display.setPosition(spacing * (i + 1), 0)
			this.add(display)
		}
		
		this.onDropped = options.onDropped
	}
	
	updateMaterials (selectedMaterials) {
		for (let i = 0; i < this.materialDisplays.length; i++) {
			const material = config.materials.find((material) => material.id === selectedMaterials[i])
			this.materialDisplays[i].updateMaterial(material)
		}
	}
}
