import Phaser from 'phaser'
import config from '../config'

export default class MaterialStorageDisplay extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.materialIcon = new Phaser.GameObjects.Image(this.scene, 0, 0, options.material.icon)
		this.materialIcon.setScale(0.3, 0.3)
		if (options.material.options && options.material.options.color) {
			this.materialIcon.setTint(options.material.options.color)
		}
		this.material = options.material
		
		this.add(this.materialIcon)
		
		this.dragZone = new Phaser.GameObjects.Zone(this.scene, 0, 0, options.width, options.height)
		this.add(this.dragZone)
		this.dragZone.setInteractive()
		this.dragZone.on('dragstart', this.onDragStart.bind(this))
		this.dragZone.on('drop', this.onDrop.bind(this))
		this.dragZone.on('drag', this.onDrag.bind(this))
		this.dragZone.on('dragend', this.onDragEnd.bind(this))
		
		this.dragStartX = 0
		this.dragStartY = 0
		this.originalPositionX = this.x
		this.originalPositionY = this.y
		
		this.setDrag(true)
		this.onDropped = options.onDropped
	}
	
	setDrag (draggable) {
		this.scene.input.setDraggable([this.dragZone], draggable)
	}
	
	updateMaterial (material) {
		if (material !== undefined) {
			this.materialIcon.setTexture(material.icon)
			if (material.options && material.options.color) {
				this.materialIcon.setTint(material.options.color)
			} else {
				this.materialIcon.clearTint()
			}
			this.material = material
			this.visible = true
		} else {
			this.visible = false
			this.material = undefined
		}
	}
	
	onDragStart (pointer, dragX, dragY) {
		this.dragStartX = this.dragZone.x
		this.dragStartY = this.dragZone.y
		this.originalPositionX = this.x
		this.originalPositionY = this.y
		if (this.scene && this.scene.children) {
			this.scene.children.bringToTop(this)
		}
	}
	
	onDrag (pointer, dragX, dragY) {
		this.setPosition(this.originalPositionX + dragX - this.dragStartX, this.originalPositionY + dragY - this.dragStartY)
	}
	
	onDrop (pointer, dropZone) {
		if (dropZone) {
			const materialId = (this.material || {}).id
			
			if (typeof this.onDropped === 'function') {
				this.onDropped()
			}
			
			this.x = this.originalPositionX
			this.y = this.originalPositionY
			
			dropZone.parentContainer.fixHole(dropZone.holeIndex, materialId)
		}
	}
	
	onDragEnd (pointer, dragX, dragY) {
		this.setDrag(false)
		this.scene.tweens.add({
			targets: this,
			x: this.originalPositionX,
			y: this.originalPositionY,
			ease: 'Linear',
			duration: config.snapBackDuration,
			repeat: 0,
			onComplete: () => {
				this.setDrag(true)
			}
		})
	}
}
