import Phaser from 'phaser'
import config from '../config'
import MaterialStorageDisplay from '../widgets/MaterialStorageDisplay'

export default class StorageDisplay extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)

		this.materialDisplays = {}
		
		const iconSpacing = this.scene.sys.canvas.width / (config.displayMaterialsPerRow + 1)
		
		this.background = new Phaser.GameObjects.Graphics(this.scene)
		this.add(this.background)
		
		this.background.fillStyle(0x6e3b28)
		this.background.lineStyle(15, 0x441d16)
		if (options.background) {
			this.background.fillRect(0, -iconSpacing / 2, this.scene.sys.canvas.width, 1000)
			
			this.background.beginPath()
			for (let i = 0; i < 4; i++) {
				this.background.moveTo(0, (i - 0.5) * iconSpacing)
				this.background.lineTo(this.scene.sys.canvas.width, (i - 0.5) * iconSpacing)
			}
			
			for (let i = 0; i < config.displayMaterialsPerRow + 1; i++) {
				this.background.moveTo((i + 0.5) * iconSpacing, -iconSpacing / 2)
				this.background.lineTo((i + 0.5) * iconSpacing, 1000)
			}
			this.background.strokePath()
		} else {
			this.background.fillRect(iconSpacing / 2, -iconSpacing / 2, this.scene.sys.canvas.width - iconSpacing, iconSpacing * 2)
			this.background.strokeRect(iconSpacing / 2, -iconSpacing / 2, this.scene.sys.canvas.width - iconSpacing, iconSpacing * 2)
			
			this.background.beginPath()
			for (let i = 1; i < 2; i++) {
				this.background.moveTo(iconSpacing / 2, (i - 0.5) * iconSpacing)
				this.background.lineTo(this.scene.sys.canvas.width - iconSpacing / 2, (i - 0.5) * iconSpacing)
			}
			
			for (let i = 1; i < config.displayMaterialsPerRow; i++) {
				this.background.moveTo((i + 0.5) * iconSpacing, -iconSpacing / 2)
				this.background.lineTo((i + 0.5) * iconSpacing, iconSpacing * 3 / 2)
			}
			this.background.strokePath()
		}
		
		let currentRow = 0
		let currentColumn = 0
		for (const material of config.materials) {
			const display = new MaterialStorageDisplay({
				scene: this.scene,
				material,
				counterTextStyle: config.counterTextStyle
			})
			this.materialDisplays[material.id] = display
			display.setPosition(iconSpacing * (currentColumn + 1), iconSpacing * currentRow)
			this.add(display)
			
			currentColumn++
			if (currentColumn >= config.displayMaterialsPerRow) {
				currentColumn = 0
				currentRow++
			}
		}
	}
	
	updateCounts (storage) {
		for (const materialId of Object.keys(storage)) {
			this.materialDisplays[materialId].updateCount(storage[materialId])
		}
	}
}
