import Phaser from 'phaser'

export default class ToolsDropper extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.dropLength = options.dropLength
		this.onFail = options.onFail
		this.onSuccess = options.onSuccess
		
		this.target = new Phaser.GameObjects.Ellipse(this.scene, 0, this.dropLength - 200, 200, 200)
		this.target.setStrokeStyle(15, 0xffffff)
		
		this.dropLine = new Phaser.GameObjects.Line(this.scene, 0, this.dropLength / 2 - 200, 0, 100, 0, this.dropLength - 300, 0xffffff)
		this.dropLine.setLineWidth(15)
		
		this.add(this.target)
		this.add(this.dropLine)
	}
	
	updateToolchain (toolchain) {
		for (const icon of this.toolIcons || []) {
			if (icon && icon.active) {
				icon.destroy()
			}
		}
		
		this.toolchain = toolchain
		this.toolIcons = []
		this.matchCount = 0
		this.toolTweens = []
		
		for (const definition of this.toolchain) {
			const iconContainer = new Phaser.GameObjects.Container(this.scene)
			const icon = new Phaser.GameObjects.Image(this.scene, 0, 0, definition.tool.icon)
			const highlight = new Phaser.GameObjects.Ellipse(this.scene, 0, 0, 200, 200)
			highlight.setFillStyle(0xffffff)
			icon.setScale(0.2, 0.2)
			if (definition.tool.options && definition.tool.options.color) {
				icon.setTint(definition.tool.options.color)
			}
			iconContainer.add(highlight)
			iconContainer.add(icon)
			iconContainer.visible = false
			this.toolTweens.push(this.scene.tweens.add({
				targets: iconContainer,
				y: this.dropLength,
				ease: 'Linear',
				duration: definition.duration,
				delay: definition.delay,
				repeat: 0,
				onStart: () => {
					iconContainer.visible = true
				},
				onComplete: () => {
					iconContainer.destroy()
					if (typeof this.onFail === 'function') {
						this.onFail()
					}
				}
			}))
			this.toolIcons.push(iconContainer)
			this.add(iconContainer)
		}
	}
	
	tryMatch (toolId) {
		if (this.toolchain[this.matchCount].tool.id === toolId && this.toolIcons[this.matchCount].y >= this.dropLength - 400 && this.toolIcons[this.matchCount].y <= this.dropLength) {
			this.toolTweens[this.matchCount].stop()
			this.toolIcons[this.matchCount].destroy()
			this.matchCount++
			if (this.matchCount >= this.toolchain.length) {
				if (typeof this.onSuccess === 'function') {
					this.onSuccess()
				}
			}
		} else {
			if (typeof this.onFail === 'function') {
				this.onFail()
			}
		}
	}
}
