import Phaser from 'phaser'
import ToolSelector from '../widgets/ToolSelector'
import config from '../config'

export default class ToolsSelection extends Phaser.GameObjects.Container {
	constructor (options) {
		super(options.scene)
		
		this.background = new Phaser.GameObjects.Graphics(this.scene)
		this.add(this.background)
		
		const spacing = this.scene.sys.canvas.width / (config.toolsPerRow + 1)
		
		this.background.fillStyle(0x441d16)
		this.background.fillRect(0, -spacing * 0.65, this.scene.sys.canvas.width, 1000)

		this.background.fillStyle(0x6e3b28)
		this.background.fillRect(0, -spacing * 0.65, this.scene.sys.canvas.width, spacing * 1.3)
		
		this.tools = []
		
		let currentRow = 0
		let currentColumn = 0
		for (let i = 0; i < config.tools.length; i++) {
			const tool = config.tools[i]
			const display = new ToolSelector({
				scene: this.scene,
				tool,
				onClick: () => {
					if (typeof options.onToolSelected === 'function') {
						options.onToolSelected(tool.id)
					}
				}
			})
			display.setPosition(spacing * (currentColumn + 1), spacing * currentRow)
			this.tools.push(display)
			this.add(display)
			currentColumn++
			if (currentColumn >= config.toolsPerRow) {
				currentColumn = 0
				currentRow++
			}
		}
	}
}
